/*=============================================================================
#  Author:          DanteZhu - http://www.vimer.cn
#  Email:           dantezhu@vip.qq.com
#  FileName:        mysql_cpp_client.cpp
#  Version:         1.0
#  LastChange:      2010-02-25 11:10:04
#  Description:     MYSQL CPP Client
#  History:
=============================================================================*/
#include "mysql_cpp_client.h"
//=============================================================================
CMySQLCppClient::CMySQLCppClient()
{/*{{{*/
    m_StrErrMsg[0]='\0';
    m_Database = NULL;
}/*}}}*/
CMySQLCppClient::~CMySQLCppClient()
{/*{{{*/
    Close();
}/*}}}*/

char* CMySQLCppClient::GetErrMsg()
{/*{{{*/
    return m_StrErrMsg;
}/*}}}*/

void CMySQLCppClient::_CloseMySQL()
{/*{{{*/
    if(m_Database)
    {
        mysql_close(m_Database);
        m_Database = NULL;
    }
}/*}}}*/

//=============================================================================
/**
 * @brief   MYSQL
 *
 * @param   ip          IP
 * @param   user        û
 * @param   pwd         
 * @param   strDb       
 *
 * @return  0           succ
 *          else        fail
 */
int CMySQLCppClient::Connect(const char* ip,const char* user,const char* pwd,const char* strDb)
{/*{{{*/
    m_MySql_Ip = ip;
    m_MySql_User = user;
    m_MySql_Pwd = pwd;
    m_MySql_Db = strDb;

    _CloseMySQL();

    // Initialize MySQL...
    m_Database = mysql_init(NULL);

    // Failed...
    if(!m_Database)
    {
        snprintf(m_StrErrMsg,MAX_ERRMSG_MYSQL,"[%s][%d][%s]Error: Unable to initialize MySQL API\n",
                __FILE__,__LINE__,__FUNCTION__);

        return CppSQLErrDBInit;
    }

    // Connect to server and check for error...
    if(mysql_real_connect(m_Database, m_MySql_Ip.c_str(), m_MySql_User.c_str(), m_MySql_Pwd.c_str(),
                m_MySql_Db.c_str(), 0, NULL, 0) < 0)
    {
        // Alert user...
        snprintf(m_StrErrMsg,MAX_ERRMSG_MYSQL,"[%s][%d][%s]Error: Unable to connect to server[%s]\n",
                __FILE__,__LINE__,__FUNCTION__,mysql_error(m_Database));

        return CppSQLErrDBConn;
    }
    return 0;
}/*}}}*/
/**
 * @brief   ִSQL
 *
 * @param   strSql      ִ
 * @param   result      ִн
 *
 * @return  0           succ
 *          else        fail
 */
int CMySQLCppClient::Execute(const char* strSql)
{/*{{{*/
    if(m_Database == NULL)
    {
        snprintf(m_StrErrMsg,MAX_ERRMSG_MYSQL,"[%s][%d][%s]Error: execute error,pointer is null\n",
                __FILE__,__LINE__,__FUNCTION__);
        return CppSQLErrSystemPointer;
    }

    if(mysql_query(m_Database, strSql) != 0)
    {
        snprintf(m_StrErrMsg,MAX_ERRMSG_MYSQL,"[%s][%d][%s]Error: Unable to execute query,errMsg=%s\n",
                __FILE__,__LINE__,__FUNCTION__,mysql_error(m_Database));
        return CppSQLErrDBExe;
    }
    return 0;
}/*}}}*/

/** 
 * @brief   Selectʱȡ
 * 
 * @param   result      ִн
 *
 * @return  0           succ
 *          else        fail
 */
int CMySQLCppClient::Result(MYSQL_RES*& result)
{/*{{{*/
    if(m_Database == NULL)
    {
        snprintf(m_StrErrMsg,MAX_ERRMSG_MYSQL,"[%s][%d][%s]Error: execute error,pointer is null\n",
                __FILE__,__LINE__,__FUNCTION__);
        return CppSQLErrSystemPointer;
    }

    // Retrieve query result from server...
    MYSQL_RES *t_Result = NULL;
    t_Result = mysql_store_result(m_Database);

    // Failed...
    if(!t_Result)
    {
        snprintf(m_StrErrMsg,MAX_ERRMSG_MYSQL,"[%s][%d][%s]Error: Unable to retrieve result\n",
                __FILE__,__LINE__,__FUNCTION__);
        return CppSQLErrDBRes;
    }
    //Ⱪ¶
    result = t_Result;
    return 0;
}/*}}}*/

/** 
 * @brief   Ӱ
 * 
 * @return  >0          succ
 *          0           ûи
 *          <0          fail
 */
int CMySQLCppClient::AffectRows()
{/*{{{*/
    int ret = mysql_affected_rows(m_Database);
    if(ret<=0)
    {
        snprintf(m_StrErrMsg,MAX_ERRMSG_MYSQL,"[%s][%d][%s]Error: AffectRows rows:[%u]\n",
                __FILE__,__LINE__,__FUNCTION__,ret);
        return CppSQLErrDBRes;
    }
    return ret;
}/*}}}*/

/** 
 * @brief   Ҫǽblobתַ
 * 
 * @param   src         Դ
 * @param   len         
 * 
 * @return  תַ
 */
string CMySQLCppClient::EscapeRealString(const char* src,unsigned int len)
{/*{{{*/
    string strEscape;
    char *escapeBuff = new char[len*2 + 1];
    mysql_real_escape_string(m_Database,escapeBuff,src,len);
    strEscape = escapeBuff;
    return strEscape;
}/*}}}*/

/**
 * @brief   رӲͷresult
 */
void CMySQLCppClient::Close()
{/*{{{*/
    _CloseMySQL();
}/*}}}*/
//=============================================================================
